.. _api:
.. module:: momoko

API
===

Classes, methods and stuff.


Connections
-----------

.. autoclass:: momoko.Pool
   :members:

.. autoclass:: momoko.Connection
   :members:



Utilities
---------

.. autoclass:: momoko.Op
   :members:


.. autoclass:: momoko.WaitOp
   :members:


.. autoclass:: momoko.WaitAllOps
   :members:


Exceptions
----------

.. autoclass:: momoko.PoolError
   :members:
